@@ -209,13 +209,13 @@ class EntryPrinter:
                 if posting.meta:
                     self.write_metadata(posting.meta, oss, '    ')
         else:
-            fmt_str = "{0}{{:{1}}}  {{:{2}}}\n".format(
+            fmt_str = "{0}{{:{1}}}  {{:{2}}}".format(
                 self.prefix, width_account, max(1, width_position))
             fmt = fmt_str.format
             for posting, account, position_str in zip(entry.postings,
                                                       strs_account,
                                                       strs_position):
-                oss.write(fmt(account, position_str))
+                print(fmt(account, position_str).rstrip(), file=oss)
                 if posting.meta:
                     self.write_metadata(posting.meta, oss, '    ')
 
@@ -267,9 +267,21 @@ class EntryPrinter:
 
     def Balance(self, entry, oss):
         comment = '   ; Diff: {}'.format(entry.diff_amount) if entry.diff_amount else ''
-        oss.write(('{e.date} balance {e.account:47} {amount}'
+        number_str = (self.dformat.format(entry.amount.number, entry.amount.currency)
+                      if isinstance(entry.amount.number, Decimal)
+                      else str(self.number))
+
+        # Render optional tolerance.
+        tolerance = ''
+        if entry.tolerance:
+            tolerance_fmt = self.dformat.format(entry.tolerance, entry.amount.currency)
+            tolerance = '~ {tolerance} '.format(tolerance=tolerance_fmt)
+
+        oss.write(('{e.date} balance {e.account:47} {amount} {tolerance}{currency}'
                    '{comment}\n').format(e=entry,
-                                         amount=entry.amount.to_string(self.dformat),
+                                         amount=number_str,
+                                         tolerance=tolerance,
+                                         currency=entry.amount.currency,
                                          comment=comment))
         self.write_metadata(entry.meta, oss)
 
